summaryrefslogtreecommitdiffstats
path: root/base/common
diff options
context:
space:
mode:
authorEndi S. Dewata <edewata@redhat.com>2014-07-01 15:36:03 -0400
committerEndi S. Dewata <edewata@redhat.com>2014-07-03 12:40:47 -0400
commit8a27f6f01a43d9c30a20ea25c9fc40793c784a49 (patch)
treef3c9724a75ef192f4e3a7eb1ef2512015c7f6406 /base/common
parentc314012f88f2e566455c9e4384f6b94c85ad9035 (diff)
downloadpki-8a27f6f01a43d9c30a20ea25c9fc40793c784a49.tar.gz
pki-8a27f6f01a43d9c30a20ea25c9fc40793c784a49.tar.xz
pki-8a27f6f01a43d9c30a20ea25c9fc40793c784a49.zip
Renamed CryptoUtil to CryptoProvider.
The CryptoUtil classes in the Python client library has been renamed to CryptoProvider for consistency with the Java client library. The cryptoutil.py module has been renamed to crypto.py. Ticket #1042
Diffstat (limited to 'base/common')
-rw-r--r--base/common/python/pki/crypto.py (renamed from base/common/python/pki/cryptoutil.py)8
-rw-r--r--base/common/python/pki/key.py4
-rw-r--r--base/common/python/pki/kra.py6
3 files changed, 9 insertions, 9 deletions
diff --git a/base/common/python/pki/key.py b/base/common/python/pki/key.py
index 048cc0d41..af34a7ff4 100644
--- a/base/common/python/pki/key.py
+++ b/base/common/python/pki/key.py
@@ -770,7 +770,7 @@ class KeyClient(object):
1) trans_wrapped_session_key is not provided by caller.
- In this case, the function will call CryptoUtil methods to generate and
+ In this case, the function will call CryptoProvider methods to generate and
wrap the session key. The function will return the KeyData object with
a private_data attribute which stores the unwrapped key information.
@@ -833,7 +833,7 @@ class KeyClient(object):
1) A passphrase is provided by the caller.
- In this case, CryptoUtil methods will be called to create the data to
+ In this case, CryptoProvider methods will be called to create the data to
securely send the passphrase to the DRM. Basically, three pieces of
data will be sent:
diff --git a/base/common/python/pki/cryptoutil.py b/base/common/python/pki/crypto.py
index 44adb3fb6..174e681b8 100644
--- a/base/common/python/pki/cryptoutil.py
+++ b/base/common/python/pki/crypto.py
@@ -30,7 +30,7 @@ import subprocess
import tempfile
-class CryptoUtil(object):
+class CryptoProvider(object):
"""
Abstract class containing methods to do cryptographic operations.
"""
@@ -93,9 +93,9 @@ class CryptoUtil(object):
pass
-class NSSCryptoUtil(CryptoUtil):
+class NSSCryptoProvider(CryptoProvider):
"""
Class that defines NSS implementation of CryptoUtil.
Requires an NSS database to have been set up and initialized.
Note that all inputs and outputs are unencoded.
@@ -126,7 +126,7 @@ class NSSCryptoUtil(CryptoUtil):
This method expects a NSS database to have already been created at
certdb_dir with password certdb_password.
"""
- CryptoUtil.__init__(self)
+ CryptoProvider.__init__(self)
self.certdb_dir = certdb_dir
self.certdb_password = certdb_password
self.nonce_iv = "e4:bb:3b:d3:c3:71:2e:58"
@@ -93,9 +93,9 @@ class CryptoUtil(object):
"""
- Class that defines NSS implementation of CryptoUtil.
+ Class that defines NSS implementation of CryptoProvider.
Requires an NSS database to have been set up and initialized.
Note that all inputs and outputs are unencoded.
diff --git a/base/common/python/pki/kra.py b/base/common/python/pki/kra.py
index e3daabdd3..6559b986b 100644
--- a/base/common/python/pki/kra.py
+++ b/base/common/python/pki/kra.py
@@ -40,13 +40,13 @@ class KRAClient(object):
""" Constructor
:param connection - PKIConnection object with DRM connection info.
:param crypto - CryptoUtil object. NSSCryptoUtil is provided by
default. If a different crypto implementation is
desired, a different subclass of CryptoUtil must be
provided.
:param transport_cert_nick - identifier for the DRM transport
certificate. This will be passed to the
- CryptoUtil.get_cert() command to get a representation
+ CryptoProvider.get_cert() command to get a representation
of the transport certificate usable for crypto ops.
Note that for NSS databases, the database must have been
initialized beforehand.
@@ -40,13 +40,13 @@ class KRAClient(object):
""" Constructor
:param connection - PKIConnection object with DRM connection info.
- :param crypto - CryptoUtil object. NSSCryptoUtil is provided by
+ :param crypto - CryptoProvider object. NSSCryptoProvider is provided by
default. If a different crypto implementation is
@@ -40,13 +40,13 @@ class KRAClient(object):
default. If a different crypto implementation is
- desired, a different subclass of CryptoUtil must be
+ desired, a different subclass of CryptoProvider must be
provided.
:param transport_cert_nick - identifier for the DRM transport